@@ -10,6 +10,9 @@
 #ifndef LIBC_BIONIC
 # define LIBC_BIONIC 3
 #endif
+#ifndef LIBC_MUSL
+# define LIBC_MUSL 4
+#endif
 #ifndef DEFAULT_LIBC
 # define DEFAULT_LIBC LIBC_GLIBC
 #endif
@@ -38,8 +41,5 @@
 #if defined IN_GCC && !defined GENERATOR_FILE
 # include "insn-modes.h"
 #endif
-#if defined IN_GCC && defined GENERATOR_FILE && !defined BITS_PER_UNIT
-#include "machmode.h"
-#endif
 # include "defaults.h"
 #endif /* GCC_TM_H */
